@@ -221,6 +221,8 @@ func forkRun(opts *ForkOptions) error {
 	} else {
 		if connectedToTerminal {
 			fmt.Fprintf(stderr, "%s Created fork %s\n", cs.SuccessIconWithColor(cs.Green), cs.Bold(ghrepo.FullName(forkedRepo)))
+		} else {
+			fmt.Fprintln(opts.IO.Out, ghrepo.GenerateRepoURL(forkedRepo, ""))
 		}
 	}
 
@@ -345,7 +347,7 @@ func forkRun(opts *ForkOptions) error {
 				forkedRepoURL := ghrepo.FormatRemoteURL(forkedRepo, protocol)
 				dir, err := gitClient.Clone(ctx, forkedRepoURL, opts.GitArgs)
 				if err == nil {
-					return dir, err
+					return dir, nil
 				}
 				var execError errWithExitCode
 				if errors.As(err, &execError) && execError.ExitCode() == 128 {
